@@ -91,7 +91,7 @@ class HestiaPi(Sensor):
     def setup(self):
         logging.debug('Setting up HestiaPi')
         self._bme280 = BME280(self.name, self.topic)
-        self._boosting_enabled_switch = HVACAuxSwitch(self.name, None, self.topic, self.aux_enabled)
+        self._boosting_enabled_switch = HVACAuxSwitch(self)
 
         for mode, pins in HVAC.HEAT_PUMP_MODES.items():
             switch = BasicSwitch(self.name, pins, '{}_{}'.format(self.topic, mode), mode)
@@ -530,9 +530,10 @@ class HestiaPi(Sensor):
 
 class HVACAuxSwitch(Switch):
 
-    def __init__(self, name, pin, topic, power_state=HVAC.ON, device_class='switch', device_type='generic_switch'):
-        super().__init__(name, pin, topic, device_class, device_type)
-        self.power_state = power_state
+    def __init__(self, thermostat):
+        super().__init__(thermostat.name, thermostat.pin, thermostat.topic, 'switch', 'generic_switch')
+        self.thermostat = thermostat
+        # self.power_state = thermostat.aux_enabled
 
     @property
     def homeassistant_mqtt_config(self):
@@ -541,21 +542,22 @@ class HVACAuxSwitch(Switch):
         return config
 
     def setup(self, lazy_setup=True):
-        # return super().setup(lazy_setup)
         # don't need any setup
         MQTT.subscribe(self.homeassistant_mqtt_config['command_topic'], self.mqtt_callback)
-        # self.on()
 
     def setup_output(self):
         # don't need to setup GPIO
         pass
 
     def on(self):
-        self.power_state = HVAC.ON
+        self.thermostat.aux_enabled = HVAC.ON
 
     def off(self):
-        self.power_state = HVAC.OFF
+        self.thermostat.aux_enabled = HVAC.OFF
 
     def state(self):
-        return self.power_state
+        self.thermostat.aux_enabled
+
+    def payload(self):
+        return self.thermostat.payload()
     
\ No newline at end of file
